@@ -2,12 +2,17 @@
 from .timer import Timer
 from .clock import Clock
 from .runcat import RunCat
+from .desktoppet import DesktopPet
+from .translator import Translator
 from .calculator import Calculator
+from .moviehelper import MovieHelper
 from .videoplayer import VideoPlayer
 from .musicplayer import MusicPlayer
 from .idcardquery import IDCardQuery
 from .portscanner import PortScanner
 from .emailsecurity import EmailSecurity
+from .earthwallpaper import EarthWallpaper
+from .computersinger import ComputerSinger
 from .inquiryexpress import InquiryExpress
 from .idiomsolitaire import IdiomSolitaire
 from .succulentquery import SucculentQuery
@@ -16,7 +21,9 @@ from .genderpredictor import GenderPredictor
 from .qrcodegenerator import QRCodeGenerator
 from .coupletgenerator import CoupletGenerator
 from .artsigngenerator import ArtSignGenerator
+from .controlpcbyemail import ControlPCbyEmail
 from .naughtyconfession import NaughtyConfession
 from .luxunsentencesquery import LuxunSentencesQuery
+from .hubbleseeonbirthday import HubbleSeeOnBirthday
 from .newyearcardgenerator import NewYearCardGenerator
 from .trumptweetsgenerator import TrumpTweetsGenerator
\ No newline at end of file
